import astropayments
from astropayments import run_call


def post(data={}):
	"""Calls /customers/disable
	Disable a customer.

	Args:
		data (dict) Key

	Returns:
		Dictionary Status
	"""
	params={}
	path='/customers/disable'
	return run_call('post','json',path,data,params)
